@@ -10,7 +10,7 @@ HTMLWidgets.widget({
       .style("height", "100%")
       .append("g")
       .attr("transform", "translate(40,0)");
-    return d3.layout.tree();
+    return d3.tree();
 
   },
 
@@ -19,11 +19,11 @@ HTMLWidgets.widget({
     /*
     var s = d3.select(el).selectAll("svg");
     s.attr("width", width).attr("height", height);
-    
+
     var margin = {top: 20, right: 20, bottom: 20, left: 20};
     width = width - margin.right - margin.left;
     height = height - margin.top - margin.bottom;
-    
+
     tree.size([height, width]);
     var svg = d3.select(el).selectAll("svg").select("g")
       .attr("transform", "translate(" + margin.left + "," + margin.top + ")");
@@ -36,12 +36,12 @@ HTMLWidgets.widget({
     // JSON array with the d3Tree root data
 
     var s = d3.select(el).selectAll("svg");
-   
+
     // when re-rendering the svg, the viewBox attribute set in the code below, will
-    // be affected by the previously set viewBox. This line ensures, that the 
-    // viewBox will always be calculated right. 
+    // be affected by the previously set viewBox. This line ensures, that the
+    // viewBox will always be calculated right.
     s.attr("viewBox", null);
-    
+
     // margin handling
     //   set our default margin to be 20
     //   will override with x.options.margin if provided
@@ -56,11 +56,11 @@ HTMLWidgets.widget({
       // commenting this out since not correct
       // s.style(["margin",ky].join("-"), margin[ky]);
     });
-      
-    
+
+
     width = s.node().getBoundingClientRect().width - margin.right - margin.left;
     height = s.node().getBoundingClientRect().height - margin.top - margin.bottom;
-    
+
     //added Math.max(1, ...) to avoid NaN values when dealing with nodes of depth 0.
     tree.size([height, width])
       .separation(function(a, b) { return (a.parent == b.parent ? 1 : 2) / Math.max(1, a.depth); });
@@ -72,16 +72,19 @@ HTMLWidgets.widget({
 
     var svg = d3.select(el).selectAll("g");
 
-    var root = x.root;
-    var nodes = tree.nodes(root),
-      links = tree.links(nodes);
+    var root = d3.hierarchy(x.root);
+    tree(root);
 
-    var diagonal = d3.svg.diagonal()
-      .projection(function(d) { return [d.y, d.x]; });
+    var diagonal = function(d, i) {
+      return "M" + d.source.y + "," + d.source.x
+                  + "C" + (d.source.y + d.target.y) / 2 + "," + d.source.x
+                  + " " + (d.source.y + d.target.y) / 2 + "," + d.target.x
+                  + " " + d.target.y + "," + d.target.x;
+    };
 
     // draw links
     var link = svg.selectAll(".link")
-      .data(links)
+      .data(root.links())
       .enter().append("path")
       .style("fill", "none")
       .style("stroke", x.options.linkColour)
@@ -91,10 +94,10 @@ HTMLWidgets.widget({
 
     // draw nodes
     var node = svg.selectAll(".node")
-      .data(nodes)
+      .data(root.descendants())
       .enter().append("g")
       .attr("class", "node")
-      .attr("transform", function(d) { 
+      .attr("transform", function(d) {
         return "translate(" + d.y + "," + d.x + ")";
       })
       .on("mouseover", mouseover)
@@ -112,57 +115,57 @@ HTMLWidgets.widget({
     node.append("text")
         .attr("dx", function(d) { return d.children ? -8 : 8; })
         .attr("dy", ".31em")
-        .attr("text-anchor", function(d) { 
+        .attr("text-anchor", function(d) {
           return d.children || d._children ? "end" : "start";
         })
         .style("font", x.options.fontSize + "px " + x.options.fontFamily)
         .style("opacity", x.options.opacity)
         .style("fill", x.options.textColour)
-        .text(function(d) { return d.name; });
-        
+        .text(function(d) { return d.data.name; });
+
     // adjust viewBox to fit the bounds of our tree
     s.attr(
         "viewBox",
         [
           d3.min(
-            s.selectAll('.node text')[0].map(function(d){
+            s.selectAll('.node text').nodes().map(function(d){
               return d.getBoundingClientRect().left
             })
           ) - s.node().getBoundingClientRect().left - margin.right,
           d3.min(
-            s.selectAll('.node text')[0].map(function(d){
+            s.selectAll('.node text').nodes().map(function(d){
               return d.getBoundingClientRect().top
             })
           ) - s.node().getBoundingClientRect().top - margin.top,
           d3.max(
-            s.selectAll('.node text')[0].map(function(d){
+            s.selectAll('.node text').nodes().map(function(d){
               return d.getBoundingClientRect().right
             })
           ) -
           d3.min(
-            s.selectAll('.node text')[0].map(function(d){
+            s.selectAll('.node text').nodes().map(function(d){
               return d.getBoundingClientRect().left
             })
           ) + margin.left + margin.right,
           d3.max(
-            s.selectAll('.node text')[0].map(function(d){
+            s.selectAll('.node text').nodes().map(function(d){
               return d.getBoundingClientRect().bottom
             })
           ) -
           d3.min(
-            s.selectAll('.node text')[0].map(function(d){
+            s.selectAll('.node text').nodes().map(function(d){
               return d.getBoundingClientRect().top
             })
           ) + margin.top + margin.bottom
         ].join(",")
-      );        
+      );
 
     // mouseover event handler
     function mouseover() {
       d3.select(this).select("circle").transition()
         .duration(750)
         .attr("r", 9);
-        
+
       d3.select(this).select("text").transition()
         .duration(750)
         .style("stroke-width", ".5px")
@@ -175,7 +178,7 @@ HTMLWidgets.widget({
       d3.select(this).select("circle").transition()
         .duration(750)
         .attr("r", 4.5);
-        
+
       d3.select(this).select("text").transition()
         .duration(750)
         .style("font", x.options.fontSize + "px " + x.options.fontFamily)
